-- Global communication functions
Communication=
	{
	Selected=1;
	Frame="CommunicationFrame";
	WindowName="CommunicationWindow";
	Options={};
	};

---------------------------------------------------------------------
-- This function will be called when speaking animation should start
-- This is supposed to be overwritten by user
--
function Communication:StartSpeaking()
end
---------------------------------------------------------------------
-- This function will be called when speaking animation should end
-- This is supposed to be overwritten by user
--
function Communication:StopSpeaking()
end

---------------------------------------------------------------------
-- Show communication options
-- Data is stored in "Options" field
--
function Communication:ShowOptions(Init)
	local c;
	for c=1,5 do
		local Text="";
		if (self.Options[c]) then
			Text = self.Options[c]
		end
		-- Set text and id
		local Frame=GetGlobal(self.Frame.."OptionsText"..c);
		Frame:Show();
		Frame:SetText(Text);
		Frame:SetId(c);
	end
	
	-- Set selection
	if (self.Options[1]) then
		self.Selected=1;
		if (Init) then
			self.Selected=Init;
		end
		GetGlobal(self.Frame.."OptionsText"..self.Selected.."Highlight"):Show();
	end
end

---------------------------------------------------------------------
-- Hide communication options
--
function Communication:HideOptions()
	local c;
	for c=1,5 do
		-- Hide all frames
		GetGlobal(self.Frame.."OptionsText"..c):Hide();
	end
end

---------------------------------------------------------------------
-- Handle keypresses
--
function Communication:OnKeyPress(Key)
	-- Check are options hidden
	if (not GetGlobal(self.Frame.."OptionsText1"):IsVisible()) then
		-- Skip line when pressing enter
		if (Keycodes:IsEnter(Key)) then
			Communication:SkipChatLine();
			return true;
		end
		-- Do nothing
		return false;
	end
	
	local Used=true;			-- Is keypress used?
	local Pos=self.Selected;	-- Selected option
	
	-- Check for keys
	if (Key==Keycodes.Up) then
		Pos=Pos-1;
		if (not self.Options[Pos]) then
			-- Loop to end
			Pos=#self.Options;
		end
	elseif (Key==Keycodes.Down) then
		Pos=Pos+1;
		if (not self.Options[Pos]) then
			-- Loop to beginning
			Pos=1;
		end
	elseif (Keycodes:IsEnter(Key)) then
		-- Select topic
		GetGlobal(self.Frame.."OptionsText"..self.Selected.."Highlight"):Hide();
		Communication:Select(self.Selected);
	else
		-- Key was not used
		Used=false;
	end
	
	-- Select this position if option exists
	if (Pos~=self.Selected and self.Options[Pos]) then
		GetGlobal(self.Frame.."OptionsText"..self.Selected.."Highlight"):Hide();
		self.Selected=Pos;
		GetGlobal(self.Frame.."OptionsText"..self.Selected.."Highlight"):Show();
	end
	
	-- Return key status
	return Used;
end
